hire.candidates:
All combinations of factors used for hiring
Description
This is a full factorial (all combinations of factors) design.
Usage
data(hire.candidates)
Arguments
Format
A data frame with 24 observations on the following 4 variables.
University
a factor with levels PrestigeExcellentGood
Sex
a factor with levels MaleFemale
Dress
a factor with levels smartmessy
Hair
a factor with levels longshort
Details
We have a toy Conjoint Analysis problem for examples.
We assume all hiring decisions are made on four
factors. This is a data set with all 24 possible
combinations.